@@ -169,10 +169,7 @@ def env_name():
     ``{env_prefix}`` and ``{env_postfix}`` fields.
     """
     env_name = find_env_name()
-    if (
-        builtins.__xonsh__.env.get("VIRTUAL_ENV_DISABLE_PROMPT")
-        or not env_name
-    ):
+    if builtins.__xonsh__.env.get("VIRTUAL_ENV_DISABLE_PROMPT") or not env_name:
         # env name prompt printing disabled, or no environment; just return
         return
 
@@ -477,7 +474,11 @@ def _get_hg_root(q):
     while True:
         if not os.path.isdir(_curpwd):
             return False
-        if any([b.name == ".hg" for b in xt.scandir(_curpwd)]):
+        try:
+            dot_hg_is_in_curwd = any([b.name == ".hg" for b in xt.scandir(_curpwd)])
+        except OSError:
+            return False
+        if dot_hg_is_in_curwd:
             q.put(_curpwd)
             break
         else:
@@ -756,7 +757,7 @@ class PromptFormatter:
         except Exception:
             print("prompt: error: on field {!r}" "".format(field), file=sys.stderr)
             xt.print_exception()
-            value = "(ERROR:{})".format(field)
+            value = "{{BACKGROUND_RED}}{{ERROR:{}}}{{NO_COLOR}}".format(field)
         return value
 
 
