@@ -1,5 +1,6 @@
 """Implements a cat command for xonsh."""
 import os
+import stat
 import time
 import builtins
 
@@ -48,8 +49,9 @@ def _cat_single_file(opts, fname, stdin, out, err, line_count=1):
         print("cat: No such file or directory: {}".format(fname), file=err)
         return True, line_count
     else:
-        file_size = os.stat(fname).st_size
-        if file_size == 0:
+        fstat = os.stat(fname)
+        file_size = fstat.st_size
+        if file_size == 0 and not stat.S_ISREG(fstat.st_mode):
             file_size = None
         fobj = open(fname, "rb")
         f = xproc.NonBlockingFDReader(fobj.fileno(), timeout=0.1)
